@@ -385,6 +385,24 @@ class TdmqClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
+    async def CreateRocketMQTopicV2(
+            self,
+            request: models.CreateRocketMQTopicV2Request,
+            opts: Dict = None,
+    ) -> models.CreateRocketMQTopicV2Response:
+        """
+        创建RocketMQ主题
+        """
+        
+        kwargs = {}
+        kwargs["action"] = "CreateRocketMQTopicV2"
+        kwargs["params"] = request._serialize()
+        kwargs["resp_cls"] = models.CreateRocketMQTopicV2Response
+        kwargs["headers"] = request.headers
+        kwargs["opts"] = opts or {}
+        
+        return await self.call_and_deserialize(**kwargs)
+        
     async def CreateRocketMQVipInstance(
             self,
             request: models.CreateRocketMQVipInstanceRequest,
@@ -1671,7 +1689,8 @@ class TdmqClient(AbstractClient):
             opts: Dict = None,
     ) -> models.DescribeRocketMQPublicAccessMonitorDataResponse:
         """
-        从腾讯云可观测平台拉取公网指标监控数据，目前仅支持客户端到 LB 的入带宽和出宽带指标。
+        查询公网指标监控数据，目前仅支持客户端到 LB 的入带宽和出宽带指标。
+        当前 API 适用集群：4.x 专享集群 和 4.x 通用集群。5.x 集群暂不支持该功能。
         """
         
         kwargs = {}
